@@ -21,36 +21,36 @@
     #include <unistd.h>
 #endif
 
-#ifdef G_OS_WIN32
-    #define LIBPREFIX ""
-#else
-    #define LIBPREFIX "lib"
-#endif
-
 static GHashTable* global_keys;
 static gchar* jsforms;
 
 static gboolean
 formhistory_prepare_js ()
 {
-   gchar* data_name;
    gchar* data_path;
    gchar* autosuggest;
    gchar* style;
    guint i;
    gchar* file;
 
-   data_name = g_build_filename (PACKAGE_NAME, "res", NULL);
-   data_path = sokoke_find_data_filename (data_name);
-   g_free (data_name);
-   file = g_build_filename (data_path, G_DIR_SEPARATOR_S, "autosuggestcontrol.js",NULL);
+   data_path = g_build_filename (PACKAGE_NAME, "res", "autosuggestcontrol.js", NULL);
+   file = sokoke_find_data_filename (data_path);
    if (!g_file_get_contents (file, &autosuggest, NULL, NULL))
+   {
+       g_free (data_path);
+       g_free (file);
        return FALSE;
+   }
    g_strchomp (autosuggest);
 
-   file = g_build_filename (data_path, G_DIR_SEPARATOR_S, "autosuggestcontrol.css",NULL);
-   if(!g_file_get_contents (file, &style, NULL, NULL))
+   katze_assign (data_path, g_build_filename (PACKAGE_NAME, "res", "autosuggestcontrol.css", NULL));
+   katze_assign (file, sokoke_find_data_filename (data_path));
+   if (!g_file_get_contents (file, &style, NULL, NULL))
+   {
+       g_free (data_path);
+       g_free (file);
        return FALSE;
+   }
    g_strchomp (style);
    i = 0;
    while (style[i])
@@ -191,7 +191,6 @@ formhistory_update_main_hash (gchar* key,
     return TRUE;
 }
 
-#if WEBKIT_CHECK_VERSION (1, 1, 4)
 static gboolean
 formhistory_navigation_decision_cb (WebKitWebView*             web_view,
                                     WebKitWebFrame*            web_frame,
@@ -251,50 +250,6 @@ formhistory_navigation_decision_cb (WebKitWebView*             web_view,
     }
     return FALSE;
 }
-#else
-static void
-formhistory_feed_keys (GHashTable* keys,
-                       gpointer    db)
-{
-    GHashTableIter iter;
-    gchar* key;
-    gchar* value;
-
-    g_hash_table_iter_init (&iter, keys);
-    while (g_hash_table_iter_next (&iter, (gpointer)&key, (gpointer)&value))
-    {
-        if (formhistory_update_main_hash (key, value))
-            formhistory_update_database (db, key, value);
-    }
-}
-
-static void
-formhistory_session_request_queued_cb (SoupSession*     session,
-                                       SoupMessage*     msg,
-                                       MidoriExtension* extension)
-{
-    gchar* method = katze_object_get_string (msg, "method");
-    if (method && !strncmp (method, "POST", 4))
-    {
-        SoupMessageBody* body = msg->request_body;
-        if (soup_message_body_get_accumulate (body))
-        {
-            SoupBuffer* buffer;
-            GHashTable* keys;
-            gpointer db;
-
-            buffer = soup_message_body_flatten (body);
-            keys = soup_form_decode (body->data);
-
-            db = g_object_get_data (G_OBJECT (extension), "formhistory-db");
-            formhistory_feed_keys (keys, db);
-            soup_buffer_free (buffer);
-            g_hash_table_destroy (keys);
-        }
-    }
-    g_free (method);
-}
-#endif
 
 static void
 formhistory_window_object_cleared_cb (WebKitWebView*  web_view,
@@ -316,13 +271,8 @@ formhistory_add_tab_cb (MidoriBrowser*   browser,
     GtkWidget* web_view = midori_view_get_web_view (view);
     g_signal_connect (web_view, "window-object-cleared",
             G_CALLBACK (formhistory_window_object_cleared_cb), NULL);
-    #if WEBKIT_CHECK_VERSION (1, 1, 4)
     g_signal_connect (web_view, "navigation-policy-decision-requested",
         G_CALLBACK (formhistory_navigation_decision_cb), extension);
-    #else
-    g_signal_connect (webkit_get_default_session (), "request-queued",
-        G_CALLBACK (formhistory_session_request_queued_cb), extension);
-    #endif
 }
 
 static void
@@ -358,13 +308,8 @@ formhistory_deactivate_tabs (MidoriView*      view,
     GtkWidget* web_view = midori_view_get_web_view (view);
     g_signal_handlers_disconnect_by_func (
        web_view, formhistory_window_object_cleared_cb, NULL);
-    #if WEBKIT_CHECK_VERSION (1, 1, 4)
     g_signal_handlers_disconnect_by_func (
        web_view, formhistory_navigation_decision_cb, extension);
-    #else
-    g_signal_handlers_disconnect_by_func (
-       webkit_get_default_session (), formhistory_session_request_queued_cb, extension);
-    #endif
 }
 
 static void
@@ -491,21 +436,6 @@ formhistory_activate_cb (MidoriExtension* extension,
 </html> */
 #endif
 
-static void
-formhistory_clear_database_cb (void)
-{
-    gchar* filename = g_build_filename (sokoke_set_config_dir (NULL),
-        "extensions", LIBPREFIX "formhistory." G_MODULE_SUFFIX, "forms.db", NULL);
-    sqlite3* db;
-    if (sqlite3_open (filename, &db) == SQLITE_OK)
-    {
-        sqlite3_exec (db, "DELETE FROM forms", NULL, NULL, NULL);
-        sqlite3_close (db);
-    }
-    g_free (filename);
-
-}
-
 MidoriExtension*
 extension_init (void)
 {
@@ -539,9 +469,5 @@ extension_init (void)
         g_signal_connect (extension, "activate",
             G_CALLBACK (formhistory_activate_cb), NULL);
 
-    /* i18n: Data entered into web forms by the user */
-    sokoke_register_privacy_item ("formhistory", _("_Form History"),
-        G_CALLBACK (formhistory_clear_database_cb));
-
     return extension;
 }
