@@ -360,6 +360,7 @@ tab_panel_view_notify_icon_cb (GtkWidget*       view,
             gtk_tree_store_set (GTK_TREE_STORE (model), &iter,
                 3, icon,
                 6, &style->bg[GTK_STATE_NORMAL],
+                7, &style->fg[GTK_STATE_NORMAL],
                 -1);
     }
 }
@@ -452,7 +453,7 @@ tab_panel_browser_add_tab_cb (MidoriBrowser*   browser,
 
         gtk_tree_store_insert_with_values (GTK_TREE_STORE (model),
             &iter, NULL, page, 0, view, 1, GTK_STOCK_CLOSE, 2, buttons,
-            3, icon, 4, title, 5, ellipsize, 6, NULL, -1);
+            3, icon, 4, title, 5, ellipsize, 6, NULL, 7, NULL, -1);
     }
 
     if (!g_signal_handler_find (view, G_SIGNAL_MATCH_FUNC,
@@ -530,8 +531,9 @@ tab_panel_app_add_browser_cb (MidoriApp*       app,
 
     panel = katze_object_get_object (browser, "panel");
 
-    model = gtk_tree_store_new (7, MIDORI_TYPE_VIEW,
-        G_TYPE_STRING, G_TYPE_BOOLEAN, GDK_TYPE_PIXBUF, G_TYPE_STRING, G_TYPE_INT, GDK_TYPE_COLOR);
+    model = gtk_tree_store_new (8, MIDORI_TYPE_VIEW,
+        G_TYPE_STRING, G_TYPE_BOOLEAN, GDK_TYPE_PIXBUF, G_TYPE_STRING,
+        G_TYPE_INT, GDK_TYPE_COLOR, GDK_TYPE_COLOR);
     g_object_set_data (G_OBJECT (browser), "tab-panel-ext-model", model);
     treeview = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (treeview), FALSE);
@@ -549,7 +551,8 @@ tab_panel_app_add_browser_cb (MidoriApp*       app,
     renderer_text = gtk_cell_renderer_text_new ();
     gtk_tree_view_column_pack_start (column, renderer_text, TRUE);
     gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (column), renderer_text,
-        "text", 4, "ellipsize", 5, "cell-background-gdk", 6, NULL);
+        "text", 4, "ellipsize", 5,
+        "cell-background-gdk", 6, "foreground-gdk", 7, NULL);
     gtk_tree_view_column_set_expand (column, TRUE);
     gtk_tree_view_append_column (GTK_TREE_VIEW (treeview), column);
     column = gtk_tree_view_column_new ();
