@@ -48,6 +48,9 @@ static const gint tb_editor_dnd_targets_len = G_N_ELEMENTS(tb_editor_dnd_targets
 
 static void tb_editor_browser_populate_tool_menu_cb(MidoriBrowser *browser, GtkWidget *menu, MidoriExtension *ext);
 
+static void tb_editor_browser_populate_toolbar_menu_cb(MidoriBrowser *browser, GtkWidget *menu,
+                                                       MidoriExtension *ext);
+
 static void tb_editor_app_add_browser_cb(MidoriApp *app, MidoriBrowser *browser, MidoriExtension *ext);
 
 
@@ -56,6 +59,7 @@ static void tb_editor_deactivate_cb(MidoriExtension *extension, MidoriBrowser *b
 	MidoriApp *app = midori_extension_get_app(extension);
 
 	g_signal_handlers_disconnect_by_func(browser, tb_editor_browser_populate_tool_menu_cb, extension);
+	g_signal_handlers_disconnect_by_func(browser, tb_editor_browser_populate_toolbar_menu_cb, extension);
 	g_signal_handlers_disconnect_by_func(extension, tb_editor_deactivate_cb, browser);
 	g_signal_handlers_disconnect_by_func(app, tb_editor_app_add_browser_cb, extension);
 }
@@ -579,10 +583,27 @@ static void tb_editor_browser_populate_tool_menu_cb(MidoriBrowser *browser, GtkW
     gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
 }
 
+static void tb_editor_browser_populate_toolbar_menu_cb(MidoriBrowser *browser, GtkWidget *menu,
+                                                       MidoriExtension *ext)
+{
+    GtkWidget* separator;
+    GtkWidget* menuitem;
+
+    separator = gtk_separator_menu_item_new ();
+    gtk_widget_show (separator);
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), separator);
+    menuitem = gtk_menu_item_new_with_mnemonic (_("_Customize..."));
+    g_signal_connect (menuitem, "activate",
+        G_CALLBACK (tb_editor_menu_configure_toolbar_activate_cb), browser);
+    gtk_widget_show (menuitem);
+    gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
+}
+
 static void tb_editor_app_add_browser_cb(MidoriApp *app, MidoriBrowser *browser, MidoriExtension *ext)
 {
-	g_signal_connect(browser, "populate-tool-menu", G_CALLBACK(tb_editor_browser_populate_tool_menu_cb), ext);
-	g_signal_connect(ext, "deactivate", G_CALLBACK(tb_editor_deactivate_cb), browser);
+    g_signal_connect(browser, "populate-tool-menu", G_CALLBACK(tb_editor_browser_populate_tool_menu_cb), ext);
+    g_signal_connect(browser, "populate-toolbar-menu", G_CALLBACK(tb_editor_browser_populate_toolbar_menu_cb), ext);
+    g_signal_connect(ext, "deactivate", G_CALLBACK(tb_editor_deactivate_cb), browser);
 }
 
 
