@@ -27,10 +27,13 @@ gtk_icon_entry_set_icon_from_pixbuf (GtkEntry*            entry,
                                      GtkEntryIconPosition position,
                                      GdkPixbuf*           pixbuf)
 {
+    gboolean activatable;
+
     /* Without this ugly hack pixbuf icons don't work */
-    gtk_widget_hide (GTK_WIDGET (entry));
+    activatable = gtk_entry_get_icon_activatable (entry, position);
     gtk_entry_set_icon_from_pixbuf (entry, position, pixbuf);
-    gtk_widget_show (GTK_WIDGET (entry));
+    gtk_entry_set_icon_activatable (entry, position, !activatable);
+    gtk_entry_set_icon_activatable (entry, position, activatable);
 }
 
 #else
@@ -64,8 +67,6 @@ gtk_icon_entry_set_icon_from_pixbuf (GtkEntry*            entry,
 	((pos) == GTK_ICON_ENTRY_PRIMARY || \
 	 (pos) == GTK_ICON_ENTRY_SECONDARY)
 
-#define GTK_ICON_ENTRY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GTK_TYPE_ICON_ENTRY, GtkIconEntryPrivate))
-
 typedef struct
 {
   GdkPixbuf *pixbuf;
@@ -81,12 +82,13 @@ typedef struct
   gboolean insensitive;
 } EntryIconInfo;
 
-typedef struct _GtkIconEntryPrivate
+struct _GtkIconEntryPrivate
 {
+  gdouble fraction;
   EntryIconInfo icons[MAX_ICONS];
 
   gulong icon_released_id;
-} GtkIconEntryPrivate;
+};
 
 enum
 {
@@ -311,9 +313,316 @@ gtk_icon_entry_editable_init (GtkEditableClass *iface)
 {
 };
 
+/* GTK+/ GtkEntry internal helper function
+   Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+   Modified by the GTK+ Team and others 1997-2000
+   Copied from Gtk+ 2.13, whitespace adjusted */
+static void
+gtk_entry_get_pixel_ranges (GtkEntry  *entry,
+                            gint     **ranges,
+                            gint      *n_ranges)
+{
+  gint start_char, end_char;
+
+  if (gtk_editable_get_selection_bounds (GTK_EDITABLE (entry),
+                                         &start_char, &end_char))
+    {
+      PangoLayout *layout = gtk_entry_get_layout (entry);
+      PangoLayoutLine *line = pango_layout_get_lines (layout)->data;
+      const char *text = pango_layout_get_text (layout);
+      gsize start_index = g_utf8_offset_to_pointer (text, start_char) - text;
+      gsize end_index = g_utf8_offset_to_pointer (text, end_char) - text;
+      gint real_n_ranges, i;
+
+      pango_layout_line_get_x_ranges (line,
+          start_index, end_index, ranges, &real_n_ranges);
+
+      if (ranges)
+        {
+          gint *r = *ranges;
+
+          for (i = 0; i < real_n_ranges; ++i)
+            {
+              r[2 * i + 1] = (r[2 * i + 1] - r[2 * i]) / PANGO_SCALE;
+              r[2 * i] = r[2 * i] / PANGO_SCALE;
+            }
+        }
+
+      if (n_ranges)
+        *n_ranges = real_n_ranges;
+    }
+  else
+    {
+      if (n_ranges)
+        *n_ranges = 0;
+      if (ranges)
+        *ranges = NULL;
+    }
+}
+
+/* GTK+/ GtkEntry internal helper function
+   Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+   Modified by the GTK+ Team and others 1997-2000
+   Copied from Gtk+ 2.13, whitespace adjusted
+   Code adjusted to not rely on internal qdata */
+static void
+_gtk_entry_effective_inner_border (GtkEntry  *entry,
+                                   GtkBorder *border)
+{
+  static const GtkBorder default_inner_border = { 2, 2, 2, 2 };
+  GtkBorder *tmp_border;
+
+  tmp_border = (GtkBorder*) gtk_entry_get_inner_border (entry);
+
+  if (tmp_border)
+    {
+      *border = *tmp_border;
+      return;
+    }
+
+  gtk_widget_style_get (GTK_WIDGET (entry), "inner-border", &tmp_border, NULL);
+
+  if (tmp_border)
+    {
+      *border = *tmp_border;
+      gtk_border_free (tmp_border);
+      return;
+    }
+
+  *border = default_inner_border;
+}
+
+static void
+gtk_entry_borders (GtkEntry* entry,
+                   gint*     xborder,
+                   gint*     yborder,
+                   gboolean* interior_focus,
+                   gint*     focus_width)
+{
+  GtkWidget *widget = GTK_WIDGET (entry);
+
+  if (entry->has_frame)
+    {
+      *xborder = widget->style->xthickness;
+      *yborder = widget->style->ythickness;
+    }
+  else
+    {
+      *xborder = 0;
+      *yborder = 0;
+    }
+
+  gtk_widget_style_get (widget, "interior-focus", interior_focus,
+                        "focus-line-width", focus_width, NULL);
+
+  if (interior_focus)
+    {
+      *xborder += *focus_width;
+      *yborder += *focus_width;
+    }
+}
+
+/* GTK+/ GtkEntry internal helper function
+   Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+   Modified by the GTK+ Team and others 1997-2000
+   Copied from Gtk+ 2.13, whitespace adjusted */
+static void
+gtk_entry_get_text_area_size (GtkEntry *entry,
+                              gint     *x,
+                              gint     *y,
+                              gint     *width,
+                              gint     *height)
+{
+  gint frame_height;
+  gint xborder, yborder;
+  gboolean interior_focus;
+  gint focus_width;
+  GtkRequisition requisition;
+  GtkWidget *widget = GTK_WIDGET (entry);
+
+  gtk_widget_get_child_requisition (widget, &requisition);
+  gtk_entry_borders (entry, &xborder, &yborder, &interior_focus, &focus_width);
+
+  if (GTK_WIDGET_REALIZED (widget))
+    gdk_drawable_get_size (widget->window, NULL, &frame_height);
+  else
+    frame_height = requisition.height;
+
+  if (GTK_WIDGET_HAS_FOCUS (widget) && interior_focus)
+      frame_height -= 2 * focus_width;
+
+  if (x)
+    *x = xborder;
+
+  if (y)
+    *y = frame_height / 2 - (requisition.height - yborder * 2) / 2;
+
+  if (width)
+    *width = GTK_WIDGET (entry)->allocation.width - xborder * 2;
+
+  if (height)
+    *height = requisition.height - yborder * 2;
+}
+
+/* GTK+/ GtkEntry internal helper function
+   Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+   Modified by the GTK+ Team and others 1997-2000
+   Copied from Gtk+ 2.13, whitespace adjusted */
+static void
+get_layout_position (GtkEntry *entry,
+                     gint     *x,
+                     gint     *y)
+{
+  PangoLayout *layout;
+  PangoRectangle logical_rect;
+  gint area_width, area_height;
+  GtkBorder inner_border;
+  gint y_pos;
+  PangoLayoutLine *line;
+
+  layout = gtk_entry_get_layout (entry);
+
+  gtk_entry_get_text_area_size (entry, NULL, NULL, &area_width, &area_height);
+  _gtk_entry_effective_inner_border (entry, &inner_border);
+
+  area_height = PANGO_SCALE *
+                (area_height - inner_border.top - inner_border.bottom);
+
+  line = pango_layout_get_lines (layout)->data;
+  pango_layout_line_get_extents (line, NULL, &logical_rect);
+
+  /* Align primarily for locale's ascent/descent */
+  y_pos = ((area_height - entry->ascent - entry->descent) / 2 +
+           entry->ascent + logical_rect.y);
+
+  /* Now see if we need to adjust to fit in actual drawn string */
+  if (logical_rect.height > area_height)
+    y_pos = (area_height - logical_rect.height) / 2;
+  else if (y_pos < 0)
+    y_pos = 0;
+  else if (y_pos + logical_rect.height > area_height)
+    y_pos = area_height - logical_rect.height;
+
+  y_pos = inner_border.top + y_pos / PANGO_SCALE;
+
+  if (x)
+    *x = inner_border.left - entry->scroll_offset;
+
+  if (y)
+    *y = y_pos;
+}
+
+/* GTK+/ GtkEntry internal helper function
+   Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
+   Modified by the GTK+ Team and others 1997-2000
+   Copied from Gtk+ 2.13, whitespace adjusted
+   Code adjusted to not rely on internal _gtk_entry_ensure_layout */
+static void
+gtk_entry_draw_text (GtkEntry *entry)
+{
+  GtkWidget *widget;
+
+  if (!entry->visible && entry->invisible_char == 0)
+    return;
+
+  if (GTK_WIDGET_DRAWABLE (entry))
+    {
+      PangoLayout *layout = gtk_entry_get_layout (entry);
+      cairo_t *cr;
+      gint x, y;
+      gint start_pos, end_pos;
+
+      widget = GTK_WIDGET (entry);
+
+      get_layout_position (entry, &x, &y);
+
+      cr = gdk_cairo_create (entry->text_area);
+
+      cairo_move_to (cr, x, y);
+      gdk_cairo_set_source_color (cr, &widget->style->text [widget->state]);
+      pango_cairo_show_layout (cr, layout);
+
+      if (gtk_editable_get_selection_bounds (GTK_EDITABLE (entry),
+                                             &start_pos, &end_pos))
+        {
+          gint *ranges;
+          gint n_ranges, i;
+          PangoRectangle logical_rect;
+          GdkColor *selection_color, *text_color;
+          GtkBorder inner_border;
+
+          pango_layout_get_pixel_extents (layout, NULL, &logical_rect);
+          gtk_entry_get_pixel_ranges (entry, &ranges, &n_ranges);
+
+          if (GTK_WIDGET_HAS_FOCUS (entry))
+            {
+              selection_color = &widget->style->base [GTK_STATE_SELECTED];
+              text_color = &widget->style->text [GTK_STATE_SELECTED];
+            }
+          else
+            {
+              selection_color = &widget->style->base [GTK_STATE_ACTIVE];
+              text_color = &widget->style->text [GTK_STATE_ACTIVE];
+            }
+
+          _gtk_entry_effective_inner_border (entry, &inner_border);
+
+          for (i = 0; i < n_ranges; ++i)
+            cairo_rectangle (cr,
+                             inner_border.left -
+                             entry->scroll_offset + ranges[2 * i],
+                             y,
+                             ranges[2 * i + 1],
+                             logical_rect.height);
+
+          cairo_clip (cr);
+
+          gdk_cairo_set_source_color (cr, selection_color);
+          cairo_paint (cr);
+
+          cairo_move_to (cr, x, y);
+          gdk_cairo_set_source_color (cr, text_color);
+          pango_cairo_show_layout (cr, layout);
+
+          g_free (ranges);
+        }
+
+      cairo_destroy (cr);
+    }
+}
+
+static gboolean
+entry_expose_event (GtkWidget*      entry,
+                    GdkEventExpose* event,
+                    GtkIconEntry*   icon_entry)
+{
+  GtkIconEntryPrivate *priv;
+  GdkWindow* text_area;
+  gint width, height;
+
+  priv = icon_entry->priv;
+  text_area = GTK_ENTRY (entry)->text_area;
+  gdk_drawable_get_size (text_area, &width, &height);
+
+  if (priv->fraction > 0.0)
+  {
+      gtk_paint_box (entry->style, text_area,
+                     GTK_STATE_SELECTED, GTK_SHADOW_OUT,
+                     &event->area, entry, "entry-progress",
+                     0, 0, priv->fraction * width, height);
+      gtk_entry_draw_text (GTK_ENTRY (entry));
+  }
+  return FALSE;
+}
+
 static void
 gtk_icon_entry_init (GtkIconEntry *entry)
 {
+  entry->priv = G_TYPE_INSTANCE_GET_PRIVATE (entry, GTK_TYPE_ICON_ENTRY,
+                                             GtkIconEntryPrivate);
+
+  g_signal_connect_after (entry, "expose-event",
+    G_CALLBACK (entry_expose_event), entry);
 }
 
 static void
@@ -354,7 +663,7 @@ gtk_icon_entry_map (GtkWidget *widget)
 
       GTK_WIDGET_CLASS (parent_class)->map (widget);
 
-      priv = GTK_ICON_ENTRY_GET_PRIVATE (widget);
+      priv = GTK_ICON_ENTRY (widget)->priv;
 
       for (i = 0; i < MAX_ICONS; i++)
 	{
@@ -384,7 +693,7 @@ gtk_icon_entry_unmap (GtkWidget *widget)
     {
       int i;
 
-      priv = GTK_ICON_ENTRY_GET_PRIVATE (widget);
+      priv = GTK_ICON_ENTRY (widget)->priv;
 
       for (i = 0; i < MAX_ICONS; i++)
 	{
@@ -501,7 +810,7 @@ get_icon_width (GtkIconEntry *entry, GtkIconEntryPosition icon_pos)
   GtkIconEntryPrivate *priv;
   EntryIconInfo *icon_info;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   if (icon_info->pixbuf == NULL)
@@ -603,7 +912,7 @@ gtk_icon_entry_realize (GtkWidget *widget)
   int i;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   GTK_WIDGET_CLASS (parent_class)->realize (widget);
 
@@ -647,7 +956,7 @@ gtk_icon_entry_unrealize (GtkWidget *widget)
   int i;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   GTK_WIDGET_CLASS (parent_class)->unrealize (widget);
 
@@ -698,7 +1007,7 @@ place_windows (GtkIconEntry *icon_entry, GtkAllocation *widget_alloc)
   GtkIconEntryPrivate *priv;
   gint y;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (icon_entry);
+  priv = icon_entry->priv;
 
   get_text_area_size (icon_entry, &text_area_alloc);
   
@@ -758,7 +1067,7 @@ get_pixbuf_from_icon (GtkIconEntry *entry, GtkIconEntryPosition icon_pos)
   EntryIconInfo *icon_info;
   GtkIconEntryPrivate *priv;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   g_object_ref (icon_info->pixbuf);
@@ -823,7 +1132,7 @@ draw_icon (GtkWidget *widget, GtkIconEntryPosition icon_pos)
   gint x, y, width, height;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   if (icon_info->pixbuf == NULL || !GTK_WIDGET_REALIZED (widget))
@@ -903,7 +1212,7 @@ gtk_icon_entry_expose (GtkWidget *widget, GdkEventExpose *event)
   g_return_val_if_fail (event != NULL, FALSE);
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   if (GTK_WIDGET_DRAWABLE (widget))
     {
@@ -948,7 +1257,7 @@ gtk_icon_entry_enter_notify (GtkWidget *widget, GdkEventCrossing *event)
   int i;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   for (i = 0; i < MAX_ICONS; i++)
     {
@@ -985,7 +1294,7 @@ gtk_icon_entry_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
   int i;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   for (i = 0; i < MAX_ICONS; i++)
     {
@@ -1014,7 +1323,7 @@ gtk_icon_entry_button_press (GtkWidget *widget, GdkEventButton *event)
   int i;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   for (i = 0; i < MAX_ICONS; i++)
     {
@@ -1047,7 +1356,7 @@ gtk_icon_entry_button_release (GtkWidget *widget, GdkEventButton *event)
   int i;
 
   entry = GTK_ICON_ENTRY (widget);
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   for (i = 0; i < MAX_ICONS; i++)
     {
@@ -1099,7 +1408,7 @@ icon_theme_changed (GtkIconEntry *entry)
   GtkIconEntryPrivate *priv;
   int i;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   for (i = 0; i < MAX_ICONS; i++)
     {
@@ -1137,7 +1446,7 @@ gtk_icon_entry_set_icon_internal (GtkIconEntry *entry,
   g_return_if_fail (GTK_IS_ICON_ENTRY (entry));
   g_return_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos));
   
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
   
   if (pixbuf == icon_info->pixbuf)
@@ -1209,7 +1518,7 @@ gtk_icon_entry_set_icon_from_pixbuf (GtkIconEntry *entry,
   g_return_if_fail (GTK_IS_ICON_ENTRY (entry));
   g_return_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos));
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   if (pixbuf == icon_info->pixbuf)
@@ -1306,7 +1615,7 @@ gtk_icon_entry_set_icon_from_icon_name (GtkIconEntry *entry,
   g_return_if_fail (GTK_IS_ICON_ENTRY (entry));
   g_return_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos));
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   screen = gtk_widget_get_screen (GTK_WIDGET (entry));
@@ -1364,7 +1673,7 @@ gtk_icon_entry_set_icon_from_gicon (const GtkIconEntry *entry,
   GError *error = NULL;
   GtkIconInfo *info;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   screen = gtk_widget_get_screen (GTK_WIDGET (entry));
@@ -1377,7 +1686,7 @@ gtk_icon_entry_set_icon_from_gicon (const GtkIconEntry *entry,
 					 GTK_ICON_SIZE_MENU,
 					 &width, &height);
 
-      #if #GTK_CHECK_VERSION (2, 14, 0)
+      #if GTK_CHECK_VERSION (2, 14, 0)
       info = gtk_icon_theme_lookup_by_gicon (icon_theme,
 					     icon,
 					     MIN (width, height), 0);
@@ -1417,7 +1726,7 @@ gtk_icon_entry_set_cursor (const GtkIconEntry *entry,
   GtkIconEntryPrivate *priv;
   GdkCursor *cursor;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   icon_info->cursor_type = cursor_type;
@@ -1449,7 +1758,7 @@ gtk_icon_entry_set_icon_highlight (const GtkIconEntry *entry,
   EntryIconInfo *icon_info;
   GtkIconEntryPrivate *priv;
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   g_return_if_fail (entry != NULL);
   g_return_if_fail (GTK_IS_ICON_ENTRY (entry));
@@ -1484,7 +1793,7 @@ gtk_icon_entry_get_pixbuf (const GtkIconEntry *entry,
   g_return_val_if_fail (GTK_IS_ICON_ENTRY (entry), NULL);
   g_return_val_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos), NULL);
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   return priv->icons[icon_pos].pixbuf;
 }
@@ -1510,7 +1819,7 @@ gtk_icon_entry_get_gicon (const GtkIconEntry *entry,
   g_return_val_if_fail (GTK_IS_ICON_ENTRY (entry), NULL);
   g_return_val_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos), NULL);
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
   icon_info = &priv->icons[icon_pos];
 
   return icon_info->storage_type == _GTK_IMAGE_GICON ? icon_info->gicon : NULL;
@@ -1535,7 +1844,7 @@ gtk_icon_entry_get_icon_highlight (const GtkIconEntry *entry,
   g_return_val_if_fail (GTK_IS_ICON_ENTRY (entry), FALSE);
   g_return_val_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos), FALSE);
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   return priv->icons[icon_pos].highlight;
 }
@@ -1561,7 +1870,7 @@ gtk_icon_entry_set_tooltip (const GtkIconEntry *entry,
   g_return_if_fail (GTK_IS_ICON_ENTRY (entry));
   g_return_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos));
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (entry);
+  priv = entry->priv;
 
   icon_info = &priv->icons[icon_pos];
 
@@ -1591,7 +1900,7 @@ gtk_icon_entry_set_icon_sensitive (const GtkIconEntry *icon_entry,
   g_return_if_fail (GTK_IS_ICON_ENTRY (icon_entry));
   g_return_if_fail (IS_VALID_ICON_ENTRY_POSITION (icon_pos));
 
-  priv = GTK_ICON_ENTRY_GET_PRIVATE (icon_entry);
+  priv = icon_entry->priv;
 
   icon_info = &priv->icons[icon_pos];
 
@@ -1606,4 +1915,19 @@ gtk_icon_entry_set_icon_sensitive (const GtkIconEntry *icon_entry,
     }
 }
 
+void
+gtk_icon_entry_set_progress_fraction (GtkIconEntry *icon_entry,
+                                      gdouble       fraction)
+{
+  GtkIconEntryPrivate *priv;
+
+  g_return_if_fail (GTK_IS_ICON_ENTRY (icon_entry));
+
+  priv = icon_entry->priv;
+  priv->fraction = CLAMP (fraction, 0.0, 1.0);
+
+  if (GTK_ENTRY (icon_entry)->text_area)
+    gdk_window_invalidate_rect (GTK_ENTRY (icon_entry)->text_area, NULL, FALSE);
+}
+
 #endif
