@@ -137,6 +137,7 @@ enum
 enum {
     ACTIVATE,
     DEACTIVATE,
+    OPEN_PREFERENCES,
 
     LAST_SIGNAL
 };
@@ -186,6 +187,24 @@ midori_extension_class_init (MidoriExtensionClass* class)
         G_TYPE_NONE, 0,
         G_TYPE_NONE);
 
+    /**
+     * MidoriExtension::open-preferences:
+     *
+     * The preferences of the extension should be opened.
+     *
+     * Since: 0.4.0
+     */
+     signals[OPEN_PREFERENCES] = g_signal_new (
+        "open-preferences",
+        G_TYPE_FROM_CLASS (class),
+        (GSignalFlags)(G_SIGNAL_RUN_LAST | G_SIGNAL_ACTION),
+        0,
+        0,
+        NULL,
+        g_cclosure_marshal_VOID__VOID,
+        G_TYPE_NONE, 0,
+        G_TYPE_NONE);
+
     gobject_class = G_OBJECT_CLASS (class);
     gobject_class->finalize = midori_extension_finalize;
     gobject_class->set_property = midori_extension_set_property;
@@ -468,6 +487,22 @@ midori_extension_is_prepared (MidoriExtension* extension)
     return FALSE;
 }
 
+/**
+ * midori_extension_has_preferences:
+ * @extension: a #MidoriExtension
+ *
+ * Determines if @extension has preferences.
+ *
+ * Return value: %TRUE if @extension has preferences
+ **/
+gboolean
+midori_extension_has_preferences (MidoriExtension* extension)
+{
+    g_return_val_if_fail (MIDORI_IS_EXTENSION (extension), FALSE);
+
+    return g_signal_has_handler_pending (extension, signals[OPEN_PREFERENCES], 0, FALSE);
+}
+
 /**
  * midori_extension_is_active:
  * @extension: a #MidoriExtension
