@@ -20,7 +20,7 @@
    Names should match with epiphany and/ or xdg spec */
 
 #define STOCK_BOOKMARK           "stock_bookmark"
-#define STOCK_BOOKMARKS          "vcard"
+#define STOCK_BOOKMARKS          "user-bookmarks"
 #define STOCK_CONSOLE            "terminal"
 #define STOCK_EXTENSION          "extension"
 #define STOCK_EXTENSIONS         "extension"
@@ -30,7 +30,7 @@
 #define STOCK_STYLE              "gnome-settings-theme"
 #define STOCK_TRANSFER           "package"
 #define STOCK_TRANSFERS          "package"
-#define STOCK_PLUGINS            GTK_STOCK_CONVERT
+#define STOCK_PLUGINS            "gnome-mime-application-x-shockwave-flash"
 
 #define STOCK_BOOKMARK_ADD       "stock_add-bookmark"
 #define STOCK_HOMEPAGE           GTK_STOCK_HOME
@@ -48,6 +48,8 @@
     #define STOCK_BOOKMARKS "general_mybookmarks_folder"
     #undef STOCK_NEWS_FEED
     #define STOCK_NEWS_FEED "general_rss"
+    #undef STOCK_WEB_BROWSER
+    #define STOCK_WEB_BROWSER "general_web"
 #endif
 
 #endif /* !__MIDORI_STOCK_H__ */
