@@ -926,6 +926,8 @@ sokoke_uri_unescape_string (const gchar* uri)
     {
         /* Preserve %20 for pasting URLs into other windows */
         gchar* unescaped = g_uri_unescape_string (uri, "+");
+        if (!unescaped)
+            return g_strdup (uri);
         gchar* spaced = sokoke_replace_variables (unescaped, " ", "%20", NULL);
         g_free (unescaped);
         return spaced;
@@ -1720,6 +1722,16 @@ sokoke_find_data_filename (const gchar* filename)
     const gchar* data_dir;
     gchar* path;
 
+    #ifdef G_OS_WIN32
+    gchar* install_path = g_win32_get_package_installation_directory_of_module (NULL);
+    path = g_build_filename (install_path, "share", filename, NULL);
+    g_free (install_path);
+    if (g_access (path, F_OK) == 0)
+        return path;
+
+    g_free (path);
+    #endif
+
     path = g_build_filename (g_get_user_data_dir (), filename, NULL);
     if (g_access (path, F_OK) == 0)
         return path;
@@ -1754,101 +1766,6 @@ sokoke_get_argv (gchar** argument_vector)
     return stored_argv;
 }
 
-#if !WEBKIT_CHECK_VERSION (1, 1, 14)
-static void
-res_server_handler_cb (SoupServer*        res_server,
-                       SoupMessage*       msg,
-                       const gchar*       path,
-                       GHashTable*        query,
-                       SoupClientContext* client,
-                       gpointer           data)
-{
-    if (g_str_has_prefix (path, "/res"))
-    {
-        gchar* filename = g_build_filename ("midori", path, NULL);
-        gchar* filepath = sokoke_find_data_filename (filename);
-        gchar* contents;
-        gsize length;
-
-        g_free (filename);
-        if (g_file_get_contents (filepath, &contents, &length, NULL))
-        {
-            gchar* content_type = g_content_type_guess (filepath, (guchar*)contents,
-                                                        length, NULL);
-            gchar* mime_type = g_content_type_get_mime_type (content_type);
-            g_free (content_type);
-            soup_message_set_response (msg, mime_type, SOUP_MEMORY_TAKE,
-                                       contents, length);
-            g_free (mime_type);
-            soup_message_set_status (msg, 200);
-        }
-        else
-            soup_message_set_status (msg, 404);
-        g_free (filepath);
-    }
-    else if (g_str_has_prefix (path, "/stock/"))
-    {
-        GtkIconTheme* icon_theme = gtk_icon_theme_get_default ();
-        const gchar* icon_name = &path[7] ? &path[7] : "";
-        gint icon_size = 22;
-        GdkPixbuf* icon;
-        gchar* contents;
-        gsize length;
-
-        if (g_ascii_isalpha (icon_name[0]))
-            icon_size = strstr (icon_name, "dialog") ? 48 : 22;
-        else if (g_ascii_isdigit (icon_name[0]))
-        {
-            guint i = 0;
-            while (icon_name[i])
-                if (icon_name[i++] == '/')
-                {
-                    gchar* size = g_strndup (icon_name, i - 1);
-                    icon_size = atoi (size);
-                    g_free (size);
-                    icon_name = &icon_name[i];
-                }
-        }
-
-        icon = gtk_icon_theme_load_icon (icon_theme, icon_name,
-            icon_size, 0, NULL);
-        if (!icon)
-            icon = gtk_icon_theme_load_icon (icon_theme, "gtk-missing-image",
-                icon_size, 0, NULL);
-
-        gdk_pixbuf_save_to_buffer (icon, &contents, &length, "png", NULL, NULL);
-        g_object_unref (icon);
-        soup_message_set_response (msg, "image/png", SOUP_MEMORY_TAKE,
-                                   contents, length);
-        soup_message_set_status (msg, 200);
-    }
-    else
-    {
-        soup_message_set_status (msg, 404);
-    }
-}
-
-SoupServer*
-sokoke_get_res_server (void)
-{
-    static SoupServer* res_server = NULL;
-    SoupAddress* addr = NULL;
-
-    if (G_UNLIKELY (!res_server))
-    {
-        addr = soup_address_new ("localhost", SOUP_ADDRESS_ANY_PORT);
-        soup_address_resolve_sync (addr, NULL);
-        res_server = soup_server_new ("interface", addr, NULL);
-        g_object_unref (addr);
-        soup_server_add_handler (res_server, "/",
-                                 res_server_handler_cb, NULL, NULL);
-        soup_server_run_async (res_server);
-    }
-
-    return res_server;
-}
-#endif
-
 gchar*
 sokoke_replace_variables (const gchar* template,
                           const gchar* variable_first, ...)
